@@ -32,7 +32,9 @@ AVAILABLE_TEMPLATES = [
     'quick-start',
     'resources-test',
     'packages',
-    'slack-bot'
+    'slack-bot',
+    'user-auth',
+    'power-tools'
 ]
 
 def create_project_cli(args):
