@@ -250,7 +250,7 @@ def _update_simple_lambda(
     # Update configuration
     # Update events
 
-    print(f"GETTING HERE")
+    
     output_task.update(
         comment=f"Updating lambda function {new_resource.name}"
     )
@@ -483,7 +483,7 @@ def _upload_s3_dependency(
     # Takes in a resource and create an s3 artifact that can be use as src code for lambda deployment
     keyname = f"{dependency.name}-{dependency.hash}.zip"
 
-    zip_location = core_paths.get_full_path_from_intermediate_base(dependency.artifact_path)
+    zip_location = core_paths.get_full_path_from_workspace_base(dependency.artifact_path)
 
     total_bytes =  os.path.getsize(zip_location)
 
@@ -586,7 +586,7 @@ def _create_simple_layer(
         "publish_layer_version",
         {
             "Content": {"S3Bucket": BUCKET, "S3Key": key_name},
-            "LayerName": f"{layer_name}_{namespace_token}",
+            "LayerName": f"{layer_name}_{namespace_token[:10]}",
             "CompatibleRuntimes": [
                 "python3.7",
                 "python3.8",
